@@ -61,6 +61,7 @@ class Interface(object):
     """
 
     score = 0
+    display_score = None
 
     def __init__(self, **kwargs):
         self.attrs = kwargs.keys()
@@ -98,6 +99,12 @@ class Interface(object):
     def get_title(self):
         return _(type(self).__name__)
 
+    def get_display_score(self):
+        return self.display_score or self.score
+
+    def get_score(self):
+        return self.score
+
     def get_search_context(self, event):
         """
         Returns a dictionary describing the data that should be indexed
@@ -426,6 +433,7 @@ class Exception(Interface):
     """
 
     score = 900
+    display_score = 1200
 
     def __init__(self, value, type=None, module=None):
         # A human readable value for the exception
@@ -493,7 +501,8 @@ class Http(Interface):
     >>>  }
     """
 
-    score = 10000
+    display_score = 10000
+    score = 800
 
     # methods as defined by http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html + PATCH
     METHODS = ('GET', 'POST', 'PUT', 'OPTIONS', 'HEAD', 'DELETE', 'TRACE', 'CONNECT', 'PATCH')
@@ -623,7 +632,7 @@ class Template(Interface):
     >>> }
     """
 
-    score = 1001
+    score = 1100
 
     def __init__(self, filename, context_line, lineno, pre_context=None, post_context=None,
                  abs_path=None):
